@@ -113,7 +113,7 @@ cb_cpu_color_changed (GsmColorButton *cp, gpointer data)
     GVariant *cpu_colors_var = g_settings_get_value (settings->gobj(), GSM_SETTING_CPU_COLORS);
     gsize children_n = g_variant_n_children(cpu_colors_var);
 
-    /* Create builder to contruct new setting with updated value for cpu i */
+    /* Create builder to construct new setting with updated value for cpu i */
     GVariantBuilder builder;
     g_variant_builder_init(&builder, G_VARIANT_TYPE_ARRAY);
 
@@ -244,6 +244,8 @@ create_sys_view (GsmApplication *app, GtkBuilder * builder)
 
         cpu_label = GTK_LABEL (gtk_label_new (NULL));
 
+        /* Reserve some space to avoid the layout changing with the values. */
+        gtk_label_set_width_chars(cpu_label, 6);
         gtk_widget_set_valign (GTK_WIDGET (cpu_label), GTK_ALIGN_CENTER);
         gtk_widget_set_halign (GTK_WIDGET (cpu_label), GTK_ALIGN_START);
         gtk_box_pack_start (temp_hbox, GTK_WIDGET (cpu_label), FALSE, FALSE, 0);
@@ -387,6 +389,7 @@ on_activate_about (GSimpleAction *, GVariant *, gpointer data)
         "comments",             _("View current processes and monitor "
                                   "system state"),
         "version",              VERSION,
+        "website",              "https://wiki.gnome.org/Apps/SystemMonitor",
         "copyright",            "Copyright \xc2\xa9 2001-2004 Kevin Vandersloot\n"
                                 "Copyright \xc2\xa9 2005-2007 Benoît Dejean\n"
                                 "Copyright \xc2\xa9 2011 Chris Kühl",
