@@ -52,7 +52,7 @@ unsigned LoadGraph::num_bars() const
 
 
 
-#define FRAME_WIDTH 4
+const int FRAME_WIDTH = 4;
 static void draw_background(LoadGraph *graph) {
     GtkAllocation allocation;
     cairo_t *cr;
@@ -210,6 +210,7 @@ load_graph_queue_draw (LoadGraph *graph)
     gtk_widget_queue_draw (GTK_WIDGET (graph->disp));
 }
 
+void load_graph_update_data (LoadGraph *graph);
 static int load_graph_update (gpointer user_data); // predeclare load_graph_update so we can compile ;)
 
 static gboolean
@@ -266,13 +267,13 @@ load_graph_draw (GtkWidget *widget,
     gint j;
     gdouble sample_width, x_offset;
 
-    /* Number of pixels wide for one graph point */
-    sample_width = (float)(graph->draw_width - graph->rmargin - graph->indent) / (float)LoadGraph::NUM_POINTS;
-    /* General offset */
-    x_offset = graph->draw_width - graph->rmargin;
-
-    /* Subframe offset */
-    x_offset += graph->rmargin - ((sample_width / graph->frames_per_unit) * graph->render_counter);
+    /* Number of pixels wide for one sample point */
+    sample_width = (double)(graph->draw_width - graph->rmargin - graph->indent) / (double)LoadGraph::NUM_POINTS;
+    /* Lines start at the right edge of the drawing,
+     * a bit outside the clip rectangle. */
+    x_offset = graph->draw_width - graph->rmargin + sample_width + 2;
+    /* Adjustment for smooth movement between samples */
+    x_offset -= sample_width * graph->render_counter / (double)graph->frames_per_unit;
 
     /* draw the graph */
 
@@ -294,16 +295,15 @@ load_graph_draw (GtkWidget *widget,
     bool drawSmooth = graph->type != LOAD_GRAPH_CPU || GsmApplication::get()->config.draw_smooth;
     for (j = graph->n-1; j >= 0; j--) {
         gdk_cairo_set_source_rgba (cr, &(graph->colors [j]));
-        if (drawStacked) {
-            cairo_move_to (cr, x_offset, graph->real_draw_height + 3.5f);
-        } else {
-            cairo_move_to (cr, x_offset, (1.0f - graph->data[0][j]) * graph->real_draw_height + 3.5f);
-        }
+        // Start drawing on the right at the correct height.
+        cairo_move_to (cr, x_offset, (1.0f - graph->data[0][j]) * graph->real_draw_height + 3.5f);
+        // then draw the path of the line.
+        // Loop starts at 1 because the curve accesses the 0th data point.
         for (i = 1; i < LoadGraph::NUM_POINTS; ++i) {
             if (graph->data[i][j] == -1.0f)
                 continue;
             if (drawSmooth) {
-              cairo_curve_to (cr,
+                cairo_curve_to (cr,
                               x_offset - ((i - 0.5f) * graph->graph_delx),
                               (1.0 - graph->data[i-1][j]) * graph->real_draw_height + 3.5,
                               x_offset - ((i - 0.5f) * graph->graph_delx),
@@ -311,15 +311,21 @@ load_graph_draw (GtkWidget *widget,
                               x_offset - (i * graph->graph_delx),
                               (1.0 - graph->data[i][j]) * graph->real_draw_height + 3.5);
             } else {
-              cairo_line_to (cr, x_offset - (i * graph->graph_delx),
+                cairo_line_to (cr, x_offset - (i * graph->graph_delx),
                               (1.0 - graph->data[i][j]) * graph->real_draw_height + 3.5);
             }
 
         }
         if (drawStacked) {
-            cairo_rel_line_to (cr, 0, graph->real_draw_height + 3.5f);
+            // Draw the remaining outline of the area:
+            // Left bottom corner
+            cairo_rel_line_to (cr, 0, graph->real_draw_height + 3.5);
+            // Right bottom corner. It's drawn far outside the visible area
+            // to avoid a weird bug where it's not filling the area it should completely.
+            cairo_rel_line_to (cr, x_offset * 2, 0);
+
             //cairo_stroke_preserve(cr);
-            //cairo_close_path(cr);
+            cairo_close_path(cr);
             cairo_fill(cr);
         } else {
             cairo_stroke (cr);
@@ -343,18 +349,16 @@ get_load (LoadGraph *graph)
 
     glibtop_get_cpu (&cpu);
 
-#undef NOW
-#undef LAST
-#define NOW  (graph->cpu.times[graph->cpu.now])
-#define LAST (graph->cpu.times[graph->cpu.now ^ 1])
+    auto NOW  = [&]() -> guint64 (&)[GLIBTOP_NCPU][N_CPU_STATES] { return graph->cpu.times[graph->cpu.now]; };
+    auto LAST = [&]() -> guint64 (&)[GLIBTOP_NCPU][N_CPU_STATES] { return graph->cpu.times[graph->cpu.now ^ 1]; };
 
     if (graph->n == 1) {
-        NOW[0][CPU_TOTAL] = cpu.total;
-        NOW[0][CPU_USED] = cpu.user + cpu.nice + cpu.sys;
+        NOW()[0][CPU_TOTAL] = cpu.total;
+        NOW()[0][CPU_USED] = cpu.user + cpu.nice + cpu.sys;
     } else {
         for (i = 0; i < graph->n; i++) {
-            NOW[i][CPU_TOTAL] = cpu.xcpu_total[i];
-            NOW[i][CPU_USED] = cpu.xcpu_user[i] + cpu.xcpu_nice[i]
+            NOW()[i][CPU_TOTAL] = cpu.xcpu_total[i];
+            NOW()[i][CPU_USED] = cpu.xcpu_user[i] + cpu.xcpu_nice[i]
                 + cpu.xcpu_sys[i];
         }
     }
@@ -371,8 +375,8 @@ get_load (LoadGraph *graph)
         float total, used;
         gchar *text;
 
-        total = NOW[i][CPU_TOTAL] - LAST[i][CPU_TOTAL];
-        used  = NOW[i][CPU_USED]  - LAST[i][CPU_USED];
+        total = NOW()[i][CPU_TOTAL] - LAST()[i][CPU_TOTAL];
+        used  = NOW()[i][CPU_USED]  - LAST()[i][CPU_USED];
 
         load = used / MAX(total, 1.0f);
         graph->data[0][i] = load;
@@ -390,9 +394,6 @@ get_load (LoadGraph *graph)
     }
 
     graph->cpu.now ^= 1;
-
-#undef NOW
-#undef LAST
 }
 
 
@@ -672,31 +673,41 @@ get_net (LoadGraph *graph)
 }
 
 
+
+void
+load_graph_update_data (LoadGraph *graph)
+{
+    // Rotate data one element down.
+    std::rotate(&graph->data[0],
+                &graph->data[LoadGraph::NUM_POINTS - 1],
+                &graph->data[LoadGraph::NUM_POINTS]);
+
+    // Replace the 0th element
+    switch (graph->type) {
+        case LOAD_GRAPH_CPU:
+            get_load(graph);
+            break;
+        case LOAD_GRAPH_MEM:
+            get_memory(graph);
+            break;
+        case LOAD_GRAPH_NET:
+            get_net(graph);
+            break;
+        default:
+            g_assert_not_reached();
+    }
+}
+
+
+
 /* Updates the load graph when the timeout expires */
 static gboolean
 load_graph_update (gpointer user_data)
 {
     LoadGraph * const graph = static_cast<LoadGraph*>(user_data);
 
-    if (graph->render_counter == graph->frames_per_unit - 1) {
-        std::rotate(&graph->data[0],
-                    &graph->data[LoadGraph::NUM_POINTS - 1],
-                    &graph->data[LoadGraph::NUM_POINTS]);
-
-        switch (graph->type) {
-            case LOAD_GRAPH_CPU:
-                get_load(graph);
-                break;
-            case LOAD_GRAPH_MEM:
-                get_memory(graph);
-                break;
-            case LOAD_GRAPH_NET:
-                get_net(graph);
-                break;
-            default:
-                g_assert_not_reached();
-        }
-    }
+    if (graph->render_counter == graph->frames_per_unit - 1)
+        load_graph_update_data(graph);
 
     if (graph->draw)
         load_graph_queue_draw (graph);
@@ -882,8 +893,10 @@ LoadGraph::LoadGraph(guint type)
 void
 load_graph_start (LoadGraph *graph)
 {
-     if (!graph->timer_index) {
-
+    if (!graph->timer_index) {
+        // Update the data two times so the graph
+        // doesn't wait one cycle to start drawing.
+        load_graph_update_data(graph);
         load_graph_update(graph);
 
         graph->timer_index = g_timeout_add (graph->speed / graph->frames_per_unit,
